==> gcc-g++-4.5.0.tar.bz2: gcc-4.5.0/libstdc++-v3/testsuite/30_threads/packaged_task/cons/alloc.cc <==
// { dg-do compile { target *-*-freebsd* *-*-netbsd* *-*-linux* *-*-solaris* *-*-cygwin *-*-darwin* alpha*-*-osf* mips-sgi-irix6* } }
// { dg-options " -std=gnu++0x -pthread" { target *-*-freebsd* *-*-netbsd* *-*-linux* alpha*-*-osf* mips-sgi-irix6* } }
// { dg-options " -std=gnu++0x -pthreads" { target *-*-solaris* } }
// { dg-options " -std=gnu++0x " { target *-*-cygwin *-*-darwin* } }
// { dg-require-cstdint "" }
// { dg-require-gthreads "" }
// { dg-require-atomic-builtins "" }

// Copyright (C) 2010 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.

#include <future>
#include <testsuite_hooks.h>
#include <testsuite_allocator.h>

int f() { return 5; }

void test01()
{
  bool test __attribute__((unused)) = true;

  using std::packaged_task;
  using std::allocator_arg;
  using __gnu_test::uneq_allocator;

  uneq_allocator<char> alloc(99);

  packaged_task<int ()> p1(allocator_arg, alloc, f); // { dg-excess-errors "" }
  VERIFY( static_cast<bool>(p1) );
  p1();
  VERIFY( p1.get_future().get() == 5 );
}

int main()
{
  test01();
  return 0;
}

==> gcc-g++-4.6.0.tar.bz2: gcc-4.6.0/libstdc++-v3/testsuite/30_threads/packaged_task/cons/alloc.cc <==
// { dg-do run { target *-*-freebsd* *-*-netbsd* *-*-linux* *-*-solaris* *-*-cygwin *-*-darwin* alpha*-*-osf* mips-sgi-irix6* } }
// { dg-options " -std=gnu++0x -pthread" { target *-*-freebsd* *-*-netbsd* *-*-linux* alpha*-*-osf* mips-sgi-irix6* } }
// { dg-options " -std=gnu++0x -pthreads" { target *-*-solaris* } }
// { dg-options " -std=gnu++0x " { target *-*-cygwin *-*-darwin* } }
// { dg-require-cstdint "" }
// { dg-require-gthreads "" }
// { dg-require-atomic-builtins "" }

// Copyright (C) 2010, 2011 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.

#include <future>
#include <testsuite_hooks.h>
#include <testsuite_allocator.h>

int f() { return 5; }

void test01()
{
  bool test __attribute__((unused)) = true;

  using std::packaged_task;
  using std::allocator_arg;
  using __gnu_test::uneq_allocator;

  uneq_allocator<char> alloc(99);

  packaged_task<int ()> p1(allocator_arg, alloc, f);
  VERIFY( p1.valid() );
  p1();
  VERIFY( p1.get_future().get() == 5 );
}

int main()
{
  test01();
  return 0;
}
